from random import randint
import json

from .dictionary import DICTIONARY


CONSONANTS = "BCDFGHJKLMNPQRSTVWXZ"


class Nouns:
    def max_siblings_vowels(self, word, n):
        counter = 0
        for l in word:
            if l not in CONSONANTS:
                counter += 1
            else:
                counter = 0
            if counter > n:
                return False
        return True

    def max_siblings_consonants(self, word, n):
        counter = 0
        for l in word:
            if l in CONSONANTS:
                counter += 1
            else:
                counter = 0
            if counter > n:
                return False
        return True

    def filter(self):
        self.nouns = [
            word
            for word in self.dictionary
            if (
                len(word) > 3
                and self.max_siblings_vowels(word, 2)
                and self.max_siblings_consonants(word, 2)
            )
        ]
        self.length = len(self.nouns)

    def random_noun(self):
        n = randint(0, self.length)
        return self.nouns[n]

    def generate(self):
        noun1 = self.random_noun()
        noun2 = self.random_noun()

        random_name = noun1[: randint(0, len(noun1))] + noun2[randint(0, len(noun2)) :]
        return random_name

    def __init__(self):
        self.dictionary = DICTIONARY
        self.filter()



import dns.resolver


def domain_fully_available(domain_name, exclusive=False, tlds=["com", "fr", "io"]):
    domains = []
    for tld in tlds:
        fqdn = domain_name + "." + tld
        try:
            dns.resolver.resolve(fqdn)
            if exclusive:
                return []
        except (
            dns.exception.Timeout,
            dns.resolver.NoAnswer,
            dns.resolver.NXDOMAIN,
            dns.resolver.NoNameservers,
        ):
            domains.append(fqdn)
        except dns.name.EmptyLabel:
            pass
    return domains



from .nouns import Nouns
from .availability import domain_fully_available


class RandomNameGenerator:
    def __init__(self, min_length=4, max_length=7, exclusive=False, tlds=["com", "fr"]):
        self.nouns = Nouns()
        self.tlds = tlds
        self.exclusive = exclusive
        self.min_length = min_length
        self.max_length = max_length

    def generate(self, number=20):
        pre_propositions = []
        while len(pre_propositions) != number:
            random_noun = self.nouns.generate()
            if (
                len(random_noun) >= self.min_length
                and len(random_noun) <= self.max_length
            ):
                domains = domain_fully_available(
                    random_noun.lower(), exclusive=self.exclusive, tlds=self.tlds
                )
                if domains:
                    print(domains)
                    pre_propositions.append(domains)
        return pre_propositions



import argparse


def parse_args():
    parser = argparse.ArgumentParser("appname")
    subparsers = parser.add_subparsers(dest="command")

    generate_parser = subparsers.add_parser(
        "generate", help="generate random app names"
    )
    generate_parser.add_argument("number", help="number names to generate")
    generate_parser.add_argument(
        "--min-length", type=int, default=4, help="minimum length of names to generates"
    )
    generate_parser.add_argument(
        "--max-length", type=int, default=8, help="maximum length of names to generates"
    )
    generate_parser.add_argument(
        "--tlds",
        type=str,
        default="com,fr",
        help="comma separated list of TLDs without spaces (e.g: com,fr)",
    )
    generate_parser.add_argument(
        "--exclusive",
        action="store_true",
        default=False,
        help="Decide wether domain should be available for all TLDs",
    )

    args = parser.parse_args()
    if getattr(args, "command", None) is None:
        parser.print_help()
        exit(0)
    return args


def main():
    args = parse_args()

    if args.command == "generate":
        from .generator import RandomNameGenerator

        generator = RandomNameGenerator(
            min_length=args.min_length,
            max_length=args.max_length,
            exclusive=args.exclusive,
            tlds=args.tlds.split(","),
        )

        print(generator.generate(args.number))


if __name__ == "__main__":
    main()



import setuptools

setuptools.setup(
    name="app-name-generator",
    description="Generate available app names",
    version="0.0.6",
    packages=setuptools.find_packages(),
    entry_points={"console_scripts": ["appname = app_name_generator.__main__:main"]},
    include_package_data=True,
    install_requires=["dnspython"],
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
)
